@@ -29,14 +29,15 @@ class Provider(BaseProvider):
         :return: String. Random of random length between min and max characters.
         """
         if min_chars is None:
-            return "".join(self.random_letter() for i in range(max_chars))
+            return "".join(self.random_letters(length=max_chars))
         else:
             assert (
                 max_chars >= min_chars), "Maximum length must be greater than or equal to minium length"
             return "".join(
-                self.random_letter() for i in range(
-                    0, self.generator.random.randint(
-                        min_chars, max_chars)))
+                self.random_letters(
+                    length=self.generator.random.randint(min_chars, max_chars),
+                )
+            )
 
     def pyfloat(self, left_digits=None, right_digits=None, positive=False):
         if left_digits is not None and left_digits < 0:
@@ -123,7 +124,7 @@ class Provider(BaseProvider):
         if variable_nb_elements:
             nb_elements = self.randomize_nb_elements(nb_elements, min=1)
 
-        for f in range(nb_elements):
+        for _ in range(nb_elements):
             yield self._random_type(value_types)
 
     def pydict(self, nb_elements=10, variable_nb_elements=True, *value_types):
